<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Režim letadlo zapnut</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Režim letadlo vypnut</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Nastavení režimu letadlo</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim letadlo</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavení Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 připojeno</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Připojování…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Út</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>St</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Čt</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pá</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Přidat rozvržení klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum a čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavení času</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>neděle</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pondělí</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>úterý</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>středa</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>čtvrtek</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>pátek</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>neděle</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Režim nerušit</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Nastavení režimu nerušit</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Režim Nerušit zapnut</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Režim Nerušit vypnut</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Režim nerušit</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Pohodlí pro oči</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Pohodlí pro oči zapnuto</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Pohodlí pro oči vypnuto</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Líbivý režim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Účelný režim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Vždy zobrazeno</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Vždy skryto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Nastavení panelu</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Klávesnice na obrazovce</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balanced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power Saver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Energie %1, %2 min zbývá</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Stav %1, %2 h %3 min zbývá</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjení %1, %2 min do úplného nabití</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjení %1, %2 h %3 min do úplného nabití</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjení %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1…</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plně nabito</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Kapacita %1, plně nabito</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Akumulátor</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uspat na disk</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlašování se</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavení správy napájení</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualizovat a vypnout</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualizovat a restartovat</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Feb</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Hlasitost</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavení zvuku</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Zrušit ztlumení</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Nastavení zvuku</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Žádná výstupní zařízení</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Hlasitost %1</translation>
    </message>
</context>
</TS>